# py-random-generator

A Random Generator for Multiple Scenarios

## Installation

`python -m pip install randgen`

## Usage

- `gen_random_int(a: int, b: int) -> int`: This function creates a random integer between a and b
- `gen_random_bytes(nbytes: int = None) -> bytes`: This function creates a random sequence of bytes
- `gen_random_urlsafe_token(nbytes: int = None) -> str`: This function creates a random string that is safe to use in URLs
- `gen_random_single_digit() -> int`: This function creates a random single digit between 0 and 9- `gen_random_true_or_false() -> bool`: This function creates a random boolean value
